@@ -30,7 +30,7 @@ static void geanypg_decrypt_verify(encrypt_data * ed)
     tempfile = tmpfile();
     if (!(tempfile))
     {
-        fprintf(stderr, "GeanyPG: %s: %s.\n", _("couldn't create tempfile"), strerror(errno));
+        g_warning("%s: %s.", _("couldn't create tempfile"), strerror(errno));
         return ;
     }
     gpgme_data_new_from_stream(&plain, tempfile);
