@@ -64,8 +64,14 @@ extern gboolean pref_vte_blinken;
 extern gchar *pref_vte_emulation;
 extern gchar *pref_vte_font;
 extern gint pref_vte_scrollback;
+
+#if !GTK_CHECK_VERSION(3, 14, 0)
 extern GdkColor pref_vte_colour_fore;
 extern GdkColor pref_vte_colour_back;
+#else
+extern GdkRGBA pref_vte_colour_fore;
+extern GdkRGBA pref_vte_colour_back;
+#endif
 
 void prefs_apply(GeanyDocument *doc);
 char *prefs_file_name(void);
